<?php

namespace Offerte\Offerte\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Offerte\Offerte\Models\Offerte;

class OffertePolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the offerte.
     *
     * @param User $user
     * @param Offerte $offerte
     *
     * @return bool
     */
    public function view(User $user, Offerte $offerte)
    {
        if ($user->canDo('offerte.offerte.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $offerte->user_id;
    }

    /**
     * Determine if the given user can create a offerte.
     *
     * @param User $user
     * @param Offerte $offerte
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('offerte.offerte.create');
    }

    /**
     * Determine if the given user can update the given offerte.
     *
     * @param User $user
     * @param Offerte $offerte
     *
     * @return bool
     */
    public function update(User $user, Offerte $offerte)
    {
        if ($user->canDo('offerte.offerte.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $offerte->user_id;
    }

    /**
     * Determine if the given user can delete the given offerte.
     *
     * @param User $user
     * @param Offerte $offerte
     *
     * @return bool
     */
    public function delete(User $user, Offerte $offerte)
    {
        if ($user->canDo('offerte.offerte.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $offerte->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
